@@ -1,7 +1,7 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "shell-maker" "0.86.1"
+(define-package "shell-maker" "20251014.1155"
   "Interaction mode for making comint shells."
   '((emacs "27.1"))
   :url "https://github.com/xenodium/shell-maker"
-  :commit "47c73c6465959b563bc2c3f0aa7e9de4d8d623bd"
-  :revdesc "47c73c646595")
+  :commit "9388492f6cb56e52a56fbdf6d5fe68c1cdff4909"
+  :revdesc "9388492f6cb5")
