@@ -4,8 +4,8 @@
 
 ;; Author: Alvaro Ramirez https://xenodium.com
 ;; URL: https://github.com/xenodium/shell-maker
-;; Package-Version: 0.86.1
-;; Package-Revision: 47c73c646595
+;; Package-Version: 20251014.1155
+;; Package-Revision: 9388492f6cb5
 ;; Package-Requires: ((emacs "27.1"))
 
 ;; This package is free software; you can redistribute it and/or modify
@@ -33,7 +33,7 @@
 
 ;;; Code:
 
-(defconst shell-maker-version "0.86.1")
+(defconst shell-maker-version "0.83.1")
 
 (require 'comint)
 (require 'goto-addr)
@@ -102,13 +102,6 @@ For example:
   :type 'directory
   :group 'shell-maker)
 
-(defcustom shell-maker-curl-executable "curl"
-  "Path to the curl executable.
-Can be a simple command name like \"curl\" if it's in PATH,
-or an absolute path like \"/usr/local/bin/curl\"."
-  :type 'string
-  :group 'shell-maker)
-
 (defcustom shell-maker-forget-file-after-clear nil
   "If non-nil, reset file path after clear command."
   :type 'boolean
@@ -161,8 +154,7 @@ or an absolute path like \"/usr/local/bin/curl\"."
   :parent comint-mode-map
   :doc "Base keymap for `shell-maker' based modes."
   "S-<return>" #'newline
-  "<remap> <rename-buffer>" #'shell-maker-rename-buffer
-  "<remap> <save-buffer>" #'shell-maker-save-session-transcript
+  "C-x C-s" #'shell-maker-save-session-transcript
   "C-M-h" #'shell-maker-mark-output)
 
 (defun shell-maker-start (config &optional no-focus welcome-function new-session buffer-name mode-line-name)
@@ -209,7 +201,6 @@ Set MODE-LINE-NAME to override the mode line name."
         `(define-derived-mode ,(shell-maker-major-mode config) comint-mode
            ,(or mode-line-name (shell-maker-config-name config))
            ,(format "Major mode for %s shell." (shell-maker-config-name config))
-           (keymap-set shell-maker-mode-map "<remap> <comint-delchar-or-maybe-eof>" #'delete-char)
            (keymap-set shell-maker-mode-map "<remap> <comint-send-input>" #'shell-maker-submit)
            (keymap-set shell-maker-mode-map "<remap> <comint-interrupt-subjob>" #'shell-maker-interrupt)
            (keymap-set shell-maker-mode-map "<remap> <comint-history-isearch-backward-regexp>" #'shell-maker-search-history))))
@@ -1025,7 +1016,7 @@ and TIMEOUT: defaults to 600ms."
       (with-temp-file data-file
         (setq-local coding-system-for-write encoding)
         (insert (shell-maker--json-encode data))))
-    (append (list shell-maker-curl-executable url
+    (append (list "curl" url
                   "--fail-with-body"
                   "--no-progress-meter"
                   "-m" (number-to-string timeout))
@@ -1282,7 +1273,7 @@ returned list is of the form:
 
 (defun shell-maker--curl-version-supported ()
   "Return t if curl version is 7.76 or newer, nil otherwise."
-  (let ((curl-version-string (shell-command-to-string (concat shell-maker-curl-executable " --version "))))
+  (let ((curl-version-string (shell-command-to-string (concat "curl --version "))))
     (when (string-match "\\([0-9]+\\.[0-9]+\\.[0-9]+\\)" curl-version-string)
       (let ((version (match-string 1 curl-version-string)))
         (version<= "7.76" version)))))
@@ -1319,38 +1310,6 @@ Use ON-OUTPUT function to monitor output text."
     (when on-output
       (funcall on-output reply))))
 
-(cl-defun shell-maker-write-output (&key config output on-output)
-  "Write OUTPUT to CONFIG shell buffer.
-
-Must be called from within the shell buffer.
-
-Use ON-OUTPUT function to monitor output text."
-  (shell-maker--write-partial-reply :config config
-                                    :reply (or output "<nil-message>")
-                                    :on-output on-output))
-
-(cl-defun shell-maker-finish-output (&key config success on-output)
-  "Finish output for CONFIG shell buffer.
-
-Must be called from within the shell buffer.
-
-SUCCESS indicates whether the command succeeded.
-Use ON-OUTPUT function to monitor output text."
-  (setq shell-maker--busy nil)
-  (let ((auto-scroll (eobp)))
-    (shell-maker--write-reply :config config
-                              :reply (save-excursion
-                                       (goto-char (point-max))
-                                       (cond ((looking-back "\n\n" nil) "")
-                                             ((looking-back "\n" nil) "\n")
-                                             (t "\n\n")))
-                              :on-output on-output
-                              :failed (not success))
-    (when auto-scroll
-      (goto-char (point-max))))
-  (when success
-    (shell-maker--write-input-ring-history config)))
-
 (defmacro shell-maker-with-auto-scroll-edit (&rest body)
   "Execute BODY, preserving point unless already at end of buffer."
   (save-restriction)
@@ -1572,6 +1531,7 @@ If BACKWARDS is non-nil, move backwards."
   "Extract all commands and respective output in TEXT with PROMPT-REGEXP.
 
 Returns a list of (command . output) cons."
+  (setq text (substring-no-properties text))
   (let ((result))
     (mapc (lambda (item)
             (let* ((values (split-string item "<shell-maker-end-of-prompt>"))
@@ -1982,18 +1942,33 @@ Of the form:
                                                                                  (shell-maker--current-request-id)))
                                                                 (buffer-live-p shell-buffer)))))
                                       (with-current-buffer shell-buffer
-                                        (shell-maker-write-output :config config
-                                                                  :output output
-                                                                  :on-output on-output)))
+                                        (shell-maker--write-partial-reply :config config
+                                                                          :reply output
+                                                                          :on-output on-output)))
                                     (setq full-output (concat full-output output))))
               (cons :finish-output (lambda (success)
                                      (when-let ((active (and (buffer-live-p shell-buffer)
                                                              (eq request-id (with-current-buffer shell-buffer
                                                                               (shell-maker--current-request-id))))))
                                        (with-current-buffer shell-buffer
-                                         (shell-maker-finish-output :config config
-                                                                    :success success
-                                                                    :on-output on-output)))
+                                         (setq shell-maker--busy nil)
+                                         (let ((auto-scroll (eobp)))
+                                           (shell-maker--write-reply :config config
+                                                                     :reply (save-excursion
+                                                                              (goto-char (point-max))
+                                                                              ;; Command output may have ended in newlines.
+                                                                              ;; Adjust final number of added newlines
+                                                                              ;; prior to printing prompt.
+                                                                              (cond ((looking-back "\n\n" nil)
+                                                                                     "")
+                                                                                    ((looking-back "\n" nil)
+                                                                                     "\n")
+                                                                                    (t
+                                                                                     "\n\n")))
+                                                                     :on-output on-output
+                                                                     :failed (not success))
+                                           (when auto-scroll
+                                             (goto-char (point-max))))))
                                      ;; Do not execute anything requiring a shell buffer
                                      ;; after this point, as on-finished or on-finished
                                      ;; subscribers may kill the shell buffers.
